@@ -1,6 +1,6 @@
 import sqlite3
 from nanoAPI.utils import err, msg
-from nanoAPI.db.model import Model
+from .model import Model
 
 
 class DB:
@@ -24,17 +24,23 @@ class DB:
         return is_booted
 
     def boot(self):
-        fields = "id INT PRIMARY KEY NOT NULL"
+        fields = "id INTEGER PRIMARY KEY AUTOINCREMENT"
         for model in self.models:
-            for field in model.get_fields():
-                fields = fields + ", " + field
-            # try:
-            self.admin.execute(
-                f"CREATE TABLE IF NOT EXISTS {model.table_name} ({fields})")
-            print(msg("BOOT", f"Model {model.__name__}"))
-            # except sqlite3.OperationalError:
-            #     print(err("MODEL", f"Model {model.__name__} already booted"))
-            fields = "id INT PRIMARY KEY NOT NULL"
+            print("\n", msg("BOOT", f"Model {model.__name__}"))
+            if issubclass(model, Model):
+                for field in model.get_fields():
+                    fields = fields + ", " + field.command
+                    print(f"\t  - {field.name}")
+                try:
+                    self.admin.execute(
+                        f"CREATE TABLE IF NOT EXISTS {model.table_name} ({fields})")
+                except sqlite3.OperationalError as sql_err:
+                    print(
+                        err(model.__name__, f"{str(sql_err)}"))
+                fields = "id INTEGER PRIMARY KEY AUTOINCREMENT"
+            else:
+                print(
+                    err(model.__name__, f"Models must be an instance of *nanoAPI.db.model.Model*"))
         self.server.commit()
 
     def __del__(self):
