@@ -1,4 +1,5 @@
 from nanoAPI.utils import log, parse_route
+import json
 
 
 class Request:
@@ -9,10 +10,8 @@ class Request:
         self.params = {}
         self.queries = parse_route(
             f"{self.url}?{environ['QUERY_STRING']}")['queries']
-        print(self.queries)
         self.content_length = int(environ.get('CONTENT_LENGTH', 0))
-        self.data = environ['wsgi.input'].read(
-            self.content_length).decode('utf-8')
+        self.data = json.loads(environ['wsgi.input'].read(self.content_length).decode('utf-8'))
 
     def __str__(self):
         return log("REQ", self.method, self.url)
